import React, { useEffect } from 'react';
import { useParams } from 'react-router-dom';

import SocialLanding from '@/containers/SocialLanding';
import useSocialCallbackHandler from '@/hooks/use-social-callback-handler';

import * as styles from './index.module.scss';

type Parameters = {
  connector: string;
};

const Callback = () => {
  const { connector: connectorId } = useParams<Parameters>();

  const { socialCallbackHandler, loading, errorMessage } = useSocialCallbackHandler();

  // SocialSignIn Callback Handler
  useEffect(() => {
    if (!connectorId) {
      return;
    }
    socialCallbackHandler(connectorId);
  }, [socialCallbackHandler, connectorId]);

  if (!connectorId) {
    return null;
  }

  return (
    <div className={styles.wrapper}>
      <SocialLanding
        className={styles.connectorContainer}
        connectorId={connectorId}
        isLoading={loading}
        message={errorMessage}
      />
    </div>
  );
};

export default Callback;
